import os
os.environ['TESTING'] = 'yes'
from io import BytesIO
import pytest

from sqlalchemy.exc import IntegrityError
import requests
import requests_mock


from website.app import create_app
from website.models import db as _db
from website.ldap import LDAPUser


@pytest.fixture
def app():
    app = create_app()
    return app


@pytest.fixture
def loggeduser(app):

    user = LDAPUser("alicehacker", {"uid": [b"alicehacker"]})

    @app.login_manager.request_loader
    def load_user(request):
        return user

    return user


@pytest.fixture
def db(app):
    _db.app = app
    with app.app_context():
        _db.create_all()
    yield _db

    _db.session.close()
    _db.drop_all()


@pytest.fixture
def auth_cls(app, client):
    from authlib.integrations.requests_client import OAuth2Session
    from authlib.oauth2.rfc7523 import ClientSecretJWT

    def custom_matcher(request):

        resp = client.open(
            request.path_url,
            headers=request.headers.items(),
            data=request.text,
            method=request.method,
            url_scheme="https",
        )

        r = requests.Response()
        r.status_code = resp.status_code
        r.headers = dict(resp.headers)
        r._content = resp.data
        return r

    adapter = requests_mock.Adapter()
    adapter.add_matcher(custom_matcher)

    def inner(*args, **kwargs):
        session = OAuth2Session(*args, **kwargs)
        session.mount("http://", adapter)
        session.mount("https://", adapter)
        return session

    return inner
