from typing import Type

from website.models import Client, Grant, Token
from authlib.oauth2.rfc7523 import ClientSecretJWT
from authlib.integrations.requests_client import OAuth2Session


def test_oauth2_invalid_redirect(
    app, loggeduser, db, client, auth_cls: Type[OAuth2Session]
):
    c = Client(
        name="testapp",
        description="testapp",
        client_id="testapp",
        client_secret="secret",
        is_confidential=True,
        scope="openid profile:read users:read",
    )
    c.redirect_uris = ["https://www.buziaczek.pl/a"]
    c.save()

    auth = auth_cls("testapp", "secret", scope="profile:write")
    authorization_endpoint = "https://localhost:5000/oauth/authorize"
    token_endpoint = "https://localhost:5000/oauth/token"
    uri, state = auth.create_authorization_url(
        authorization_endpoint, redirect_uri="https://www.buziaczek.pl/b"
    )

    resp = client.post(uri, data={"confirm": "yes"})
    assert resp.status_code == 400
    assert resp.json["error_description"] == 'Invalid "redirect_uri" in request.'


def test_oauth2_no_scope(app, loggeduser, db, client, auth_cls: Type[OAuth2Session]):
    c = Client(
        name="testapp",
        description="testapp",
        client_id="testapp",
        client_secret="secret",
        is_confidential=True,
        scope="openid profile:read users:read",
    )
    c.redirect_uris = ["https://www.wykop.pl", "https://www.buziaczek.pl"]
    c.save()

    auth = auth_cls("testapp", "secret", scope="profile:write foo:bar")
    authorization_endpoint = "https://localhost:5000/oauth/authorize"
    token_endpoint = "https://localhost:5000/oauth/token"
    uri, state = auth.create_authorization_url(authorization_endpoint)
    resp = client.post(uri, data={"confirm": "yes"})
    token = auth.fetch_token(token_endpoint, authorization_response=resp.location)


def test_oauth2_ok(app, loggeduser, db, client, auth_cls: Type[OAuth2Session]):
    c = Client(
        name="testapp",
        description="testapp",
        client_id="testapp",
        client_secret="secret",
        is_confidential=True,
        scope="openid profile:read users:read",
    )
    c.redirect_uris = ["https://www.wykop.pl", "https://www.buziaczek.pl"]
    c.save()

    auth = auth_cls("testapp", "secret", scope="profile:read")
    authorization_endpoint = "https://localhost:5000/oauth/authorize"
    token_endpoint = "https://localhost:5000/oauth/token"
    uri, state = auth.create_authorization_url(
        authorization_endpoint, redirect_uri="https://www.wykop.pl"
    )
    resp = client.post(uri, data={"confirm": "yes"})
    token = auth.fetch_token(
        token_endpoint,
        authorization_response=resp.location,
        redirect_uri="https://www.wykop.pl",
    )
