import re
from urllib.parse import urlparse

from flask import jsonify, request
from ..routes import bp
from ..oauth2 import require_oauth
from ..config import ISSUER_URL, RESPONSE_TYPES_SUPPORTED, SCOPES_SUPPORTED
from ..ldap import LDAPUser

# OpenIDConnect userinfo
@bp.route("/api/1/userinfo")
@require_oauth("profile:read")
def api_userinfo():
    user = LDAPUser.by_login(request.oauth.user)
    groups = []
    if user.is_staff:
        groups.append("staff")
    return jsonify(
        sub=user.username,
        name=user.gecos,
        email=user.email,
        preferred_username=user.username,
        nickname=user.username,
        user_name=user.username,
        user_id=user.username,
        groups=groups,
    )


@bp.route("/.well-known/openid-configuration")
def oidc_configuration():
    return jsonify({
        "issuer": ISSUER_URL,
        "authorization_endpoint": f"{ISSUER_URL}/oauth/authorize",
        "token_endpoint": f"{ISSUER_URL}/oauth/token",
        "userinfo_endpoint": f"{ISSUER_URL}/api/1/userinfo",
        "jwks_uri": f"{ISSUER_URL}/jwks.json",
        "scopes_supported": SCOPES_SUPPORTED,  # recommended
        "response_types_supported": RESPONSE_TYPES_SUPPORTED,
        "subject_types_supported": ["pairwise"],
        "id_token_signing_alg_values_supported": ["RS256", "none"],
    })


@bp.route("/.well-known/webfinger")
def webfinger():
    ne = urlparse(ISSUER_URL).netloc
    acct = re.search(r'([a-z]+)@{}'.format(ne), request.args['resource'])
    return jsonify({
        "subject": f"acct:{acct}",
        "links":
        [
            {
                "rel": "http://openid.net/specs/connect/1.0/issuer",
                "href": ISSUER_URL
            }
        ]
    })
